@@ -6,7 +6,7 @@ use Moo;
 use HTML::TableContent::Parser;
 use HTML::TableContent::Table;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 has parser => (
     is      => 'rw',
@@ -132,78 +132,90 @@ sub create_table {
     my ($self, $options) = @_; 
 
     my $table_options = delete $options->{table} || { };
-    my $aoa = delete $options->{aoa};
-
-    croak 'create_tables currently requires an array of arrays representing the data.'
-        unless scalar @{ $aoa };
 
     my $table = $self->add_table($table_options);
     
+    if ( exists $options->{aoa} ) {
+        $table = $self->_create_from_aoa($table, $options);
+    }
+    elsif ( exists $options->{aoh} ) {
+       $table = $self->_create_from_aoh($table, $options);
+    }
+    else {
+        croak 'create_tables currently requires an array of arrays or an array of hashes representing the data.';
+     }
+
+    return $table;
+}
+
+sub _create_from_aoh {
+    my ($self, $table, $options) = @_;
+
+    my $aoh = $options->{aoh};
+    my @headers = keys %{ $aoh->[0] };
+    
+    if (my $order = $options->{order}){
+        my @heads = ( );
+        foreach my $header (@{ $order }) {
+            push @heads, grep { $_ =~ m/$header/ixms } @headers;
+        }
+        @headers = @heads;
+    }
+
     unless ( defined $options->{no_headers} ) {
-        my $headers = shift @{ $aoa };
+        for (@headers) {
+            my $header_options = $self->_create_options('header', $options);
+            $header_options->{text} = $_;
+            $table->add_header($header_options);
+        }
+        @headers = $table->all_headers;
+    }
 
-        foreach my $header ( @{ $headers } ) {
-            my $header_options = { };
-            
-            if ( my $head_base = $options->{header} ) {
-                for ( keys %{ $head_base } ){
-                    $header_options->{$_} = $head_base->{$_};
-                 }
+    foreach my $hash ( @{ $aoh } ) {
+        $options->{cells} =  $options->{rows}->[0]->{cells}; 
+        my $row_options = $self->_create_options('row', $options);
+        my $row = $table->add_row($row_options);
+        for (@headers) {
+            my $text = defined $options->{no_headers} ? $_ : $_->text;
+            my $cell_options = $self->_create_options('cell', $options);
+            $cell_options->{text} = $hash->{$text};
+            my $cell = $row->add_cell($cell_options);
+            unless ( defined $options->{no_headers} ) {
+                $cell->header($_);
+                push @{ $_->cells }, $cell;
             }
-
-            if ( defined $options->{headers} && scalar @{ $options->{headers} } ) {
-                my $first = shift @{ $options->{headers} };
-                for (keys %{ $first }) {
-                    $header_options->{$_} = $first->{$_}; 
-                }
-            }
-
-            $header_options->{text} = $header;
-
-            my $header = $table->add_header($header_options);
         }
     }
 
-    foreach my $array ( @{ $aoa } ) {
-        my $row_options = { };
+    return $table;
+}
 
-        if ( my $row_base = $options->{row} ) {
-            for ( keys %{ $row_base } ) {
-                $row_options->{$_} = $row_base->{$_};
-            }
-        }
+sub _create_from_aoa {
+    my ($self, $table, $options) = @_;
 
-        if ( defined $options->{rows} && scalar @{ $options->{rows} } ) {
-            my $first = shift @{ $options->{rows} };
-            for ( keys %{ $first } ) {
-                $row_options->{$_} = $first->{$_};
-            }
-        }
+    my @aoa = @{ $options->{aoa}};
 
-        my $cells = [ ];
-        if ( defined $row_options->{cells} ) {
-            $cells = delete $row_options->{cells};
+    unless ( defined $options->{no_headers} ) {
+        my $headers = shift @aoa;
+
+        foreach my $header ( @{ $headers }) {
+            my $header_options = $self->_create_options('header', $options);
+
+            $header_options->{text} = $header;
+            $table->add_header($header_options);
         }
+    }
 
+    for my $array ( @aoa ) {
+        $options->{cells} = $options->{rows}->[0]->{cells};
+        my $row_options = $self->_create_options('row', $options);
         my $row = $table->add_row($row_options);
         
-        foreach my $text ( @{ $array } ) {
-            my $cell_options = { };
-
-            if ( my $cell_base = $options->{cell} ) {
-                for ( keys %{ $cell_base } ) {
-                    $cell_options->{$_} = $cell_base->{$_};
-                }
-            }
-
-            if ( defined $cells && scalar @{ $cells } ) {
-                my $first = shift @{ $cells };
-                for ( keys %{ $first } ) {
-                    $cell_options->{$_} = $first->{$_};
-                }
-            }
-
+        for my $text ( @{ $array } ) {
+            my $cell_options = $self->_create_options('cell', $options);
+            
             $cell_options->{text} = $text;
+            
             my $cell = $row->add_cell($cell_options);
             $table->parse_to_column($cell);
         }
@@ -212,6 +224,29 @@ sub create_table {
     return $table;
 }
 
+sub _create_options {
+    my ($self, $element, $options) = @_;
+
+    my $element_options = { };
+    
+    if ( my $base = $options->{$element} ) {
+        for ( keys %{ $base } ) {
+            $element_options->{$_} = $base->{$_};
+        }
+    }
+
+    my $elements = $element . 's';
+
+    if ( my $custom = $options->{$elements} ) {
+        my $first = shift @{ $options->{$elements} };
+        for ( keys %{ $first } ) {
+            $element_options->{$_} = $first->{$_};
+        }
+    }
+
+    return $element_options;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -224,7 +259,7 @@ HTML::TableContent - Extract content from HTML tables.
 
 =head1 VERSION
 
-Version 0.09 
+Version 0.10 
 
 =cut
 
@@ -383,15 +418,23 @@ sensible which generally means mapping the text to the selector it finds closest
 
 =head2 create_table
 
-Accepts a HashRef of options, it currently requires an Array of Arrays as its data.
+Accepts a HashRef of options, it currently requires an Array of Arrays or an Array or Hashes as its data.
 
     $t->create_table({ aoa => $aoa });
 
-It will Assume the first array in the array of arrays is the array containing table headers. 
+    ...
+
+    $t->create_table({ aoh => $aoh });
+
+It will Assume the first array in the array of arrays is the array containing table headers, or for a hash its keys.
 You can turn off headers by including the no_headers flag.
 
     $t->create_table({ aoa => $aoa, no_headers => 1 });
 
+Hashes have no orderd, so to overcome this pass in an array of headers.
+
+    $t->create_table({ aoh => $aoh, order => qw/id name address/ });
+
 You can also set class, id, colspan, rowspan, style.
 
     my $options = {
