@@ -3,7 +3,7 @@ package HTML::TableContent::Element;
 use Moo;
 use HTML::TableContent::Table;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 my @ATTRIBUTE = qw/class id style colspan rowspan/;
 
@@ -163,7 +163,7 @@ HTML::TableContent::Element - attributes, text, data, class, id
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
@@ -258,6 +258,12 @@ Get Nested table by index.
 
     $element->get_nested(1);
 
+=head2 links
+
+ArrayRef of href links.
+
+    $element->links;
+
 =head1 AUTHOR
 
 LNATION, C<< <thisusedtobeanemail at gmail.com> >>
