@@ -6,7 +6,7 @@ use HTML::TableContent::Table::Caption;
 use HTML::TableContent::Table::Header;
 use HTML::TableContent::Table::Row;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 extends 'HTML::TableContent::Element';
 
@@ -22,6 +22,48 @@ has '+html_tag' => (
     default => 'table',
 );
 
+around raw => sub {
+    my ( $orig, $self ) = ( shift, shift );
+
+    my $table = $self->$orig(@_);
+
+    if ( defined $self->caption ) { $table->{caption} = $self->caption->text }
+
+    my @headers =  map { $_->raw } $self->all_headers;
+    $table->{headers} = \@headers;
+
+    my @rows =  map { $_->raw} $self->all_rows;
+    $table->{rows} = \@rows;
+
+    return $table;
+};
+
+sub aoa {
+    my $aoa = [ ];
+    
+    my @headers = map { $_->data->[0] } $_[0]->all_headers;
+    if ( scalar @headers > 0 ) {
+        push @{ $aoa }, \@headers;
+    }
+
+    for ( $_[0]->all_rows ) {
+       my @row = map { $_->data->[0] } $_->all_cells;
+       push @{ $aoa }, \@row; 
+    }
+    
+    return $aoa;
+};
+
+sub aoh {
+    my $aoh = [ ];
+    for ($_[0]->all_rows) {
+        my $hash = { };
+        map { $hash->{$_->header->data->[0]} = $_->data->[0] } $_->all_cells;
+        push @{ $aoh }, $hash;
+    }
+    return $aoh;
+};
+
 sub add_caption { 
     my $caption = HTML::TableContent::Table::Caption->new($_[1]);   
     $_[0]->caption($caption);
@@ -74,22 +116,6 @@ sub clear_first_header { return shift @{ $_[0]->headers } }
 
 sub clear_last_header { return $_[0]->clear_header( $_[0]->header_count - 1 ); }
 
-around raw => sub {
-    my ( $orig, $self ) = ( shift, shift );
-
-    my $table = $self->$orig(@_);
-
-    if ( defined $self->caption ) { $table->{caption} = $self->caption->text }
-
-    my @headers =  map { $_->raw } $self->all_headers;
-    $table->{headers} = \@headers;
-
-    my @rows =  map { $_->raw} $self->all_rows;
-    $table->{rows} = \@rows;
-
-    return $table;
-};
-
 sub _render_element {
     my $args = $_[0]->attributes;
     
@@ -171,8 +197,8 @@ sub parse_to_column {
     my $row = $self->get_last_row;
 
     my $header;
-    if ( $row->header ) {
-        $header = $row->header;
+    if ( my $row_header = $row->header ) {
+        $header = $row_header;
     }
     else {
         my $cell_index = $row->cell_count;
@@ -233,7 +259,6 @@ sub _dedupe_object_array_not_losing_order {
     return @new_items;
 }
 
-
 sub _filter_headers {
     my ( $self, @headers ) = @_;
 
@@ -255,7 +280,6 @@ sub _filter_headers {
     return 1;
 }
 
-
 sub clear_column {
     my ($self, @headers) = @_;
 
@@ -278,6 +302,29 @@ sub clear_column {
     return 1;
 }
 
+sub sort { 
+    my ($self, $options) = @_;
+
+    if ( my $order = $options->{order}) {
+        my $headers = [ ];
+        foreach my $header (@{ $order }) {
+            push @{ $headers }, grep { $_->text =~ m/$header/ixms } $self->all_headers;
+        }
+        
+        $self->headers($headers);
+        
+        foreach my $row ( $self->all_rows ) {
+            my $cells = [ ];
+            foreach my $header (@{ $order }) {
+                push @{ $cells }, grep { $_->header->text =~ m/$header/ixms } $row->all_cells;
+            }
+            $row->cells($cells); 
+        }
+    }
+
+    return $self;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -290,7 +337,7 @@ HTML::TableContent::Table - Base class for table's
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
@@ -333,6 +380,18 @@ Render the table as HTML.
 
     $table->render;
 
+=head2 aoa
+
+Return table as Array of Arrays.
+
+    $table->aoa;
+
+=head2 aoh
+
+Return table as Array of Hashes.
+
+    $table->aoh;
+
 =head2 attributes
 
 HashRef of Table attributes
